@@ -35,12 +35,7 @@ fn try_deserialize() -> Option<Config> {
     let full_config: Sections = match toml::from_slice(&content) {
         Ok(config) => config,
         Err(err) => {
-            let _ = writeln!(
-                &mut io::stderr(),
-                "Warning: {}: {}",
-                config_path.display(),
-                err
-            );
+            let _ = writeln!(io::stderr(), "Warning: {}: {}", config_path.display(), err);
             return None;
         }
     };
